/**************************************************************

   Program Title:  TinyLCD Controller
   
   Program Name:  TinyLCD_Controller.c	  Version: 0.87
   
   Author:  SS/WR	  					  Date:  February 29, 2008

   This program demonstrates the ST Electronics three axis 
   programmable accelerometer and the LCD. 



   Fuse settings should be:  F9 DF E2
   
   Copyright 2004-2008, SOC Robotics, Inc.  All rights reserved.
   
****************************************************************/
/*
 * Copyright 2004-2008, SOC Robotics, Inc.  All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of the copyright holders nor the names of
 *    contributors may be used to endorse or promote products derived
 *    from this software without specific prior written permission.
 * 4. Redistribution is only allowed in combination with SOC Machines, 
 *    Inc. hardware products.
 *
 * THIS SOFTWARE IS PROVIDED BY SOC MACHINES, INC. AND CONTRIBUTORS
 * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
 * LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS
 * FOR A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL SOC MACHINES, 
 * INC. OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING,
 * BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS
 * OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED
 * AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF
 * THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
 * SUCH DAMAGE.
 *
 * For additional information see http://www.soc-robotics.com
 */


#include <iom168v.h>
#include <macros.h>
#include <string.h>
#include <stdlib.h>
#include <math.h>
//#include <stdio.h>
#include "TinyLCD_Uart.h"
#include "TinyLCD_Defines.h"
#include "TinyLCD_Extern.h"
#include "USI_TWI_Slave.h"

#include "SmartLCD_Accelerometer.h"
#include "SmartLCD_LCD.h"
#include "SmartLCD_Buttons.h"


//  Variable declarations
unsigned int intelsuperaddress,oldpage,oldbyteoffset,totalrxcnt;
unsigned int rtccountdown1,rtccountdown2,rtccountdown3,rtccountdown4;
unsigned int mseccountdown1,mseccountdown2,mseccountdown3,mseccountdown4;
unsigned int mseccountdown5;
unsigned int seconds,minutes,hours,days;

unsigned int totalbytecnt,xoncnt,xoffcnt;
unsigned char frameerror,dataoverrun,numstrg[9];
unsigned char rtcclockcnt;

char key1state,key2state,key3state,key4state;
char key1toggle,key2toggle,key3toggle,key4toggle;

extern int _textmode;

/* Static Variables */
unsigned char UART_RxBuf[UART_RX_BUFFER_SIZE];
unsigned char UART_RxHead;
unsigned char UART_RxTail;
unsigned char UART_TxBuf[UART_TX_BUFFER_SIZE];
unsigned char UART_TxHead;
unsigned char UART_TxTail;
char  xoffsent, xonsent, enablexonoff, echoinchars,sendxoff;
char  rxcnt,checkflag,rxcntmax;
unsigned char  instrg[8],vlow,vhigh,hexbyte[3];

unsigned char FlashAddress[3];
const char signon1[] = "\n\r\n\rLED8 Monitor V0.86\n\r";

// Function declarations
unsigned char EEPROMwrite(int,unsigned char);
unsigned char EEPROMread(int);

// Sample TWI transmission commands
#define TWI_CMD_MASTER_WRITE 0x00
#define TWI_CMD_MASTER_READ  0x01

// TBD - how many bytes can be transmitted per 2-wire operation?
#define MESSAGEBUF_SIZE       4

//  Set default slave address
#define    TWI_SLAVEADDRESS		 0x15




void main()
{
 	unsigned char sw1=0,sw2=0,sw3=0,sw4=0;
 	int level=0;
 	unsigned char temp[13];
	unsigned char temp1[13];
	Init_AVR();
    Init_LCD();
    Clear_LCD();     
    Adjust_VoltageVolume();
	
	setAccelerometerRange(ACCELEROMETER_1g5);
	enableAccelerometer(ON);
	
    SplashScreen();
	Adjust_VoltageVolume();
	
    DisplayLCDBuffers();
	


	while(1) {
			 //see which button if any was pressed 
			 if (buttonState(SW1) == ON)
			 {
			  	while(buttonState(SW1) == ON);//wait till its off
				
				sw1 = ~sw1;
				sw4 = 0;//we will want switch 4 off
			 }
			 
			 if (buttonState(SW2) == ON)
			 {
 			  	while(buttonState(SW2) == ON);//wait till its off
				
				sw2 = ~sw2;
			 }
			 if (buttonState(SW3) == ON)
			 {
 			  	while(buttonState(SW3) == ON);//wait till its off
				
				sw3 = ~sw3;
			 }
			 if (buttonState(SW4) == ON)
			 {
 			  	while(buttonState(SW4) == ON);//wait till its off
				
				sw4 = ~sw4;
				sw1 = 0;//we will want sw1 off
			 }
			 
			 
			 
			 //do something depending on which button is on
			 if(sw1)
			 { 
			      PutStringinBuffer(0,0,"System");
				  PutStringinBuffer(1,0,"time is");
			  	  DisplayTime(2,0);
				  PutStringinBuffer(3,0,"");
			 }else if(sw4)
			 {
			  	   strcpy(temp1,"G Readings");
				   PutStringinBuffer(0,0,temp1);				  
			 
			       printint(readAccelerometer(X_AXIS), temp);
				   strcpy(temp1,"X=");
	 		 	   strcat(temp1,temp);
				   PutStringinBuffer(1,0,temp1);
					
				   printint(readAccelerometer(Y_AXIS), temp);
				   strcpy(temp1,"Y=");
	 		 	   strcat(temp1,temp);
				   PutStringinBuffer(2,0,temp1);
					
				   printint(readAccelerometer(Z_AXIS), temp);
				   strcpy(temp1,"Z=");
	 		 	   strcat(temp1,temp);
				   PutStringinBuffer(3,0,temp1);
			 }else
			 {
			        PutStringinBuffer(0,0,"Push a");
					PutStringinBuffer(1,0,"button");
					PutStringinBuffer(2,0,"to change");
					PutStringinBuffer(3,0,"the display");
			  }
			  
			  if(sw2)
			  {
			  	  LCD_Battery(level);
			 	  LCD_Antenna(level++);
			 	  if(level==7) level = 1;
			  }
			  if (sw3)
			  {
			  	   LCD_Rsymbol(ON);
			  }
			  else
			  {
			  	   LCD_Rsymbol(OFF);
			  }
			 
			 
			 
			 
			 
			 //ensures LCD contrast is ok
			 Adjust_VoltageVolume();
			 DisplayLCDBuffers();
			 LongDelay(10);
			} 
		
	    
}
